"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useContextStore = exports.ProstoreContext = void 0;
var react_1 = require("react");
/**
 * React context which holds mapping of store names to their instances.
 * Used as the IoC container for store injection into the components
 */
exports.ProstoreContext = react_1.createContext(null);
/**
 * Extracts store from the context based on the provided name,
 * or simply uses the provided instance
 *
 * @param storeOrName - store instance to be used, or store name to be injected from the context
 */
function useContextStore(storeOrName) {
    var context = react_1.useContext(exports.ProstoreContext);
    if (typeof storeOrName === 'string') {
        var store = context[storeOrName];
        if (!store) {
            throw new Error("Store '" + storeOrName + "' is not registered in the context");
        }
        return store;
    }
    return storeOrName;
}
exports.useContextStore = useContextStore;
//# sourceMappingURL=ProstoreContext.js.map