import { useEffect, useState } from 'react';
/**
 * Subscribe to Observable
 */
export function useObservable(obs$, setState) {
    useEffect(function () {
        var sub = obs$.subscribe(function (state) {
            setState(state);
        });
        return function () {
            sub.unsubscribe();
        };
    }, [obs$, setState]);
}
/**
 * Subscribe to Observable with useState included
 */
export function useObservableState(obs$, initialState) {
    if (initialState === void 0) { initialState = null; }
    var _a = useState(initialState), state = _a[0], setState = _a[1];
    useObservable(obs$, setState);
    return state;
}
/**
 * Subscribe to BehaviorSubject
 */
export function useSubject(sub$) {
    return useObservableState(sub$, sub$.value);
}
//# sourceMappingURL=useObservable.js.map