import { DependencyList } from 'react';
import { CheckRequestResult, CheckRequestStateFn, IRequestState, RequestStore } from '@proscom/prostore';
export interface UseRequestStoreResult<State> {
    check: CheckRequestResult;
    state: State;
    load: () => Promise<State>;
}
/**
 * Attached component to the provided store and requests data based on the variables and options
 *
 * @param storeOrName - RequestStore to subscribe to, or its name for it to be injected from the context
 * @param variables - Request variables. If they change, request will be fired again
 * @param options - Additional request options. They are not observed
 * @param checkRequest - Optional function which may be used to override default behavior of determining
 *  when to fire the request
 */
export declare function useRequestStore<Vars, Data, Options>(storeOrName: string | RequestStore<Vars, Data, Options>, variables: Vars, options?: Partial<Options>, checkRequest?: CheckRequestStateFn<Vars, Data>): UseRequestStoreResult<IRequestState<Vars, Data>>;
/**
 * The same as useRequestStore, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 */
export declare function useRequestStoreVars<Vars, Data>(storeOrName: string | RequestStore<Vars, Data, any>, variableCreator: () => Vars, args: DependencyList): UseRequestStoreResult<IRequestState<Vars, Data>>;
