import { useContext, createContext } from 'react';
import { IStore } from '@proscom/prostore';

export type IProstoreContext = {
  [name: string]: IStore<any>;
};

export type StoreOrName<Store> = string | Store;

/**
 * React context which holds mapping of store names to their instances.
 * Used as the IoC container for store injection into the components
 */
export const ProstoreContext = createContext<IProstoreContext>(null);

/**
 * Extracts store from the context based on the provided name,
 * or simply uses the provided instance
 *
 * @param storeOrName - store instance to be used, or store name to be injected from the context
 */
export function useContextStore<Store extends IStore<any>>(
  storeOrName: StoreOrName<Store>
): Store {
  const context = useContext(ProstoreContext);

  if (typeof storeOrName === 'string') {
    const store = context[storeOrName];
    if (!store) {
      throw new Error(
        `Store '${storeOrName}' is not registered in the context`
      );
    }
    return store as Store;
  }

  return storeOrName;
}
